
/*
 *  dyncnn is a deep-learning algorithm for the prediction of
 *  interacting object dynamics
 *
 *  Copyright (c) 2016 Idiap Research Institute, http://www.idiap.ch/
 *  Written by Francois Fleuret <francois.fleuret@idiap.ch>
 *
 *  This file is part of dyncnn.
 *
 *  dyncnn is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License version 3 as
 *  published by the Free Software Foundation.
 *
 *  dyncnn is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with dyncnn.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef CANVAS_CAIRO_H
#define CANVAS_CAIRO_H

#include "canvas.h"

#include <stdio.h>
#include <cairo.h>

class CanvasCairo : public Canvas {
  scalar_t _scale;
  cairo_surface_t *_image;
  cairo_t *_context_resource;

public:
  const static int _depth = 4;
  int _actual_width, _actual_height;
  unsigned char *_data;

  CanvasCairo(scalar_t scale, int nb_rows, int nb_cols, CanvasCairo **ca);
  CanvasCairo(scalar_t scale, int width, int height);
  CanvasCairo(int nb_rows, int nb_cols, CanvasCairo **x);

  virtual ~CanvasCairo();

  virtual void clear();
  virtual void set_line_width(scalar_t w);
  virtual void set_drawing_color(scalar_t r, scalar_t g, scalar_t b);
  virtual void draw_polygon(int filled, int nb, scalar_t *x, scalar_t *y);
  virtual void write_png(FILE *file);
};

#endif
